==> qtjambi-webenginewidgets-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWebEngineWidgets/QWebEngineClientCertificateSelection_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineWidgets/qwebengineclientcertificateselection.h>
#include <QtCore/QVariant>
#include <QtCore/qurl.h>
#include <QtNetwork/qsslcertificate.h>
#include <QtCore/QVector>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWebEngineClientCertificateSelection(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWebEngineClientCertificateSelection")
    QWebEngineClientCertificateSelection *_ptr = reinterpret_cast<QWebEngineClientCertificateSelection *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWebEngineClientCertificateSelection(QWebEngineClientCertificateSelection)
void __qt_construct_QWebEngineClientCertificateSelection_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebEngineClientCertificateSelection(QWebEngineClientCertificateSelection)")
    jobject arg__1 = __java_arguments[0].l;
    const QWebEngineClientCertificateSelection& __qt_arg__1 = qtjambi_cast<const QWebEngineClientCertificateSelection& >(__jni_env, arg__1);
    QWebEngineClientCertificateSelection *__qt_this = new(__qtjambi_ptr) QWebEngineClientCertificateSelection(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QWebEngineClientCertificateSelection
void __qt_destruct_QWebEngineClientCertificateSelection(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWebEngineClientCertificateSelection")
    reinterpret_cast<QWebEngineClientCertificateSelection*>(ptr)->~QWebEngineClientCertificateSelection();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineClientCertificateSelection::QWebEngineClientCertificateSelection(QWebEngineClientCertificateSelection)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineClientCertificateSelection_initialize_1native__Lio_qt_webengine_widgets_QWebEngineClientCertificateSelection_2Lio_qt_webengine_widgets_QWebEngineClientCertificateSelection_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebEngineClientCertificateSelection::QWebEngineClientCertificateSelection(QWebEngineClientCertificateSelection)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebEngineClientCertificateSelection_0, sizeof(QWebEngineClientCertificateSelection), typeid(QWebEngineClientCertificateSelection), false, &deleter_QWebEngineClientCertificateSelection, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineClientCertificateSelection::certificates()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineClientCertificateSelection_certificates_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineClientCertificateSelection *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineClientCertificateSelection::certificates()const", __qt_this)
        QVector<QSslCertificate> __qt_return_value = __qt_this->certificates();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineClientCertificateSelection::host()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineClientCertificateSelection_host_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineClientCertificateSelection *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineClientCertificateSelection::host()const", __qt_this)
        QUrl __qt_return_value = __qt_this->host();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineClientCertificateSelection::operator=(QWebEngineClientCertificateSelection)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineClientCertificateSelection_assign_1native_1cref_1QWebEngineClientCertificateSelection__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineClientCertificateSelection *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineClientCertificateSelection::operator=(QWebEngineClientCertificateSelection)", __qt_this)
        const QWebEngineClientCertificateSelection& __qt_arg__1 = QtJambiAPI::objectReferenceFromNativeId<QWebEngineClientCertificateSelection>(__jni_env, arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineClientCertificateSelection::select(QSslCertificate)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineClientCertificateSelection_select_1native_1cref_1QSslCertificate__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID certificate0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineClientCertificateSelection *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineClientCertificateSelection::select(QSslCertificate)", __qt_this)
        const QSslCertificate& __qt_certificate0 = QtJambiAPI::objectReferenceFromNativeId<QSslCertificate>(__jni_env, certificate0);
        __qt_this->select(__qt_certificate0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineClientCertificateSelection::selectNone()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineClientCertificateSelection_selectNone_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineClientCertificateSelection *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineClientCertificateSelection::selectNone()", __qt_this)
        __qt_this->selectNone();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeCustomStructors)
void* custom_constructor_QWebEngineClientCertificateSelection(void* placement, const void * __in_var)
{
    Q_UNUSED(placement)
    const QWebEngineClientCertificateSelection* copy = static_cast<const QWebEngineClientCertificateSelection*>(__in_var);
    Q_UNUSED(copy)
    if(copy){
        return new(placement) QWebEngineClientCertificateSelection(*copy);
    }else{
        return nullptr;
    }
}
// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineClientCertificateSelection_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWebEngineClientCertificateSelection *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWebEngineClientCertificateSelection(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QWebEngineClientCertificateSelection>("QWebEngineClientCertificateSelection", "io/qt/webengine/widgets/QWebEngineClientCertificateSelection");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWebEngineClientCertificateSelection, {
        ConstructorInfo(&__qt_construct_QWebEngineClientCertificateSelection_0, "Lio/qt/webengine/widgets/QWebEngineClientCertificateSelection;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWebEngineClientCertificateSelection);
    registerMetaType<QWebEngineClientCertificateSelection>("QWebEngineClientCertificateSelection", &custom_constructor_QWebEngineClientCertificateSelection);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-webenginewidgets-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiWebEngineWidgets/QWebEngineClientCertificateSelection_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineWidgets/qwebengineclientcertificateselection.h>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qurl.h>
#if __has_include(<QtNetwork/qsslcertificate.h>)
#include <QtNetwork/qsslcertificate.h>
#endif

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWebEngineClientCertificateSelection(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWebEngineClientCertificateSelection")
    QWebEngineClientCertificateSelection *_ptr = reinterpret_cast<QWebEngineClientCertificateSelection *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWebEngineClientCertificateSelection(QWebEngineClientCertificateSelection)
void __qt_construct_QWebEngineClientCertificateSelection_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebEngineClientCertificateSelection(QWebEngineClientCertificateSelection)")
    jobject arg__1 = __java_arguments[0].l;
    const QWebEngineClientCertificateSelection& __qt_arg__1 = qtjambi_cast<const QWebEngineClientCertificateSelection& >(__jni_env, arg__1);
    QWebEngineClientCertificateSelection *__qt_this = new(__qtjambi_ptr) QWebEngineClientCertificateSelection(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QWebEngineClientCertificateSelection
void __qt_destruct_QWebEngineClientCertificateSelection(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWebEngineClientCertificateSelection")
    reinterpret_cast<QWebEngineClientCertificateSelection*>(ptr)->~QWebEngineClientCertificateSelection();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineClientCertificateSelection::QWebEngineClientCertificateSelection(QWebEngineClientCertificateSelection)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineClientCertificateSelection_initialize_1native__Lio_qt_webengine_widgets_QWebEngineClientCertificateSelection_2Lio_qt_webengine_widgets_QWebEngineClientCertificateSelection_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebEngineClientCertificateSelection::QWebEngineClientCertificateSelection(QWebEngineClientCertificateSelection)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebEngineClientCertificateSelection_0, sizeof(QWebEngineClientCertificateSelection), typeid(QWebEngineClientCertificateSelection), false, &deleter_QWebEngineClientCertificateSelection, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineClientCertificateSelection::certificates()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineClientCertificateSelection_certificates_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineClientCertificateSelection *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineClientCertificateSelection::certificates()const", __qt_this)
        QVector<QSslCertificate> __qt_return_value = __qt_this->certificates();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineClientCertificateSelection::host()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineClientCertificateSelection_host_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineClientCertificateSelection *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineClientCertificateSelection::host()const", __qt_this)
        QUrl __qt_return_value = __qt_this->host();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineClientCertificateSelection::operator=(QWebEngineClientCertificateSelection)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineClientCertificateSelection_assign_1native_1cref_1QWebEngineClientCertificateSelection__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineClientCertificateSelection *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineClientCertificateSelection::operator=(QWebEngineClientCertificateSelection)", __qt_this)
        const QWebEngineClientCertificateSelection& __qt_arg__1 = QtJambiAPI::objectReferenceFromNativeId<QWebEngineClientCertificateSelection>(__jni_env, arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineClientCertificateSelection::select(QSslCertificate)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineClientCertificateSelection_select_1native_1cref_1QSslCertificate__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID certificate0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineClientCertificateSelection *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineClientCertificateSelection::select(QSslCertificate)", __qt_this)
        const QSslCertificate& __qt_certificate0 = QtJambiAPI::valueReferenceFromNativeId<QSslCertificate>(certificate0);
        __qt_this->select(__qt_certificate0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineClientCertificateSelection::selectNone()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineClientCertificateSelection_selectNone_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineClientCertificateSelection *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineClientCertificateSelection::selectNone()", __qt_this)
        __qt_this->selectNone();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeCustomStructors)
void* custom_constructor_QWebEngineClientCertificateSelection(void* placement, const void * __in_var)
{
    Q_UNUSED(placement)
    const QWebEngineClientCertificateSelection* copy = static_cast<const QWebEngineClientCertificateSelection*>(__in_var);
    Q_UNUSED(copy)
    if(copy){
        return new(placement) QWebEngineClientCertificateSelection(*copy);
    }else{
        return nullptr;
    }
}
// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_widgets_QWebEngineClientCertificateSelection_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWebEngineClientCertificateSelection *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineClientCertificateSelection>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWebEngineClientCertificateSelection(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QWebEngineClientCertificateSelection>("QWebEngineClientCertificateSelection", "io/qt/webengine/widgets/QWebEngineClientCertificateSelection");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWebEngineClientCertificateSelection, {
        ConstructorInfo(&__qt_construct_QWebEngineClientCertificateSelection_0, "Lio/qt/webengine/widgets/QWebEngineClientCertificateSelection;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWebEngineClientCertificateSelection);
    registerMetaType<QWebEngineClientCertificateSelection>("QWebEngineClientCertificateSelection", &custom_constructor_QWebEngineClientCertificateSelection);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
